## Settings
palette("default")

update_geom_defaults("bar",   list(fill = "grey70", colour = "grey40"))
scale_colour_discrete <- function(...) scale_colour_brewer(..., palette="Set2")
scale_fill_discrete <- function(...) scale_fill_colorblind()
auTheme <- theme_grey()  + 
    theme(panel.background =   element_rect(colour = NA, fill = "grey90")) +
    theme(plot.background =   element_rect(colour = NA, fill = "grey90")) +
    theme(legend.background =   element_rect(fill = "grey90")) +
    theme(plot.title = element_text(vjust = 2)) 
theme_set(auTheme)

## ----olyHW----
data(oly12, package="VGAMdata")
ggplot(oly12, aes(Height, Weight)) + geom_point() +
       ggtitle("Athletes at the London Olympics 2012")

## ----DrinksW1----
data(DrinksWages, package="HistData")
ggplot(DrinksWages, aes(drinks/n, wage)) + geom_point() +
       xlab("Proportion of drinkers") + xlim(0,1) + ylim(0,40)

## ----dwcode1----
## with(DrinksWages, hist(n, breaks=0:max(n)))
## with(DrinksWages, table(n))

## ----dwcode2----
## with(DrinksWages, max(n[drinks==0]))
## with(DrinksWages, trade[drinks==0 & n==max(n[drinks==0])])
## with(DrinksWages, max(n[sober==0]))
## with(DrinksWages, trade[sober==0 & n==max(n[sober==0])])

## ----drinkScats----
bigDW <- filter(DrinksWages, n > 4)
ggplot(bigDW, aes(drinks/n, wage)) + geom_point() +
       xlab("Proportion of drinkers") + xlim(0,1) +  ylim(0,40)

## ----geyScat----
data(geyser, package="MASS")
ggplot(geyser, aes(duration, waiting)) + geom_point()

## ----geyDens----
ggplot(geyser, aes(duration, waiting)) + geom_point() +
       geom_density2d()

## ----geyHDR----
library(hdrcde)
par(mar=c(3.1, 4.1, 1.1, 2.1))
with(geyser, hdr.boxplot.2d(duration, waiting, 
     show.points=TRUE, prob=c(0.01,0.05,0.5,0.75)))

## ----movieScat----
ggplot(movies, aes(votes, rating)) + geom_point() + ylim(1,10)

## ----mpgWt----
data(Cars93, package="MASS")
ggplot(Cars93, aes(Weight, MPG.city)) + geom_point() +
       geom_smooth(colour="green") + ylim(0,50)

## ----PearsonLines----
data(father.son, package="UsingR")
ggplot(father.son, aes(fheight, sheight)) + geom_point() +
       geom_smooth(method="lm", colour="red") +
       geom_abline(slope=1, intercept=0)

## ----fscode1----
## data(father.son, package="UsingR")
## m1 <- lm(sheight~fheight, father.son)
## summary(m1)
## par(mfrow=c(2,2))
## plot(m1)

## ----PearsonSmooth----
data(father.son, package="UsingR")
ggplot(father.son, aes(fheight, sheight)) + geom_point() +
       geom_smooth(method="lm", colour="red", se=FALSE) +
       stat_smooth()

## ----olycode1----
## ggplot(oly12, aes(Height, Weight)) +
##        geom_point(size = 1) + facet_wrap(~Sex, ncol=1)

## ----olycode2----
## oly12JWW <- filter(oly12, Sport %in%
##             c("Judo", "Weightlifting", "Wrestling"))
## ggplot(oly12JWW, aes(Height, Weight)) +
##        geom_point(size = 1) + facet_wrap(~Sport) +
##        ggtitle("Weight and Height by Sport")

## ----olyMscat----
oly12S <- within(oly12, Sport <- abbreviate(Sport, 12))
ggplot(oly12S, aes(Height, Weight)) + 
       geom_point(size = 1) + facet_wrap(~Sport) +
       ggtitle("Weight and Height by Sport")

## ----UScrimspl----
data(crime.us, package="VGAMdata")
crime.usR <- crime.us
names(crime.usR) <- gsub("*Rate", "", names(crime.usR))
names(crime.usR)[19:20] <- c("Larceny", "MotorVTheft")
ggpairs(crime.usR[, c(13:16, 18:20)],
        title="Crime rates in the USA",
        diag=list(continuous='density'), axisLabels='none')

## ----bankSwiss----
library(car)
data(bank, package="gclus")
par(mar=c(1.1, 1.1, 1.1, 1.1))
spm(select(bank, Length:Diagonal), pch=c(16, 16),
    diagonal="histogram", smoother=FALSE,
    reg.line=FALSE, groups=bank$Status)

## ----cpairscode1----
## library(gclus)
## judge.cor <- cor(USJudgeRatings)
## judge.color <- dmat.color(judge.cor)
## cpairs(USJudgeRatings, panel.colors=judge.color,
##        pch=".", gap=.5)

## ----gpairscode1----
## library(gpairs)
## data(Leaves)
## gpairs(Leaves[1:10], lower.pars=list(scatter='loess'))

## ----pairsmodcode1----
## library(SMPracticals)
## data(mathmarks)
## pairs.mod(mathmarks)

